@@ -175,7 +175,7 @@ static const uint8_t byte_decode_trees[][5] = {
 // Wrapper function invoked to read more data from the input. This mostly just
 // calls the real function that does the read. However, when the end of file
 // is reached, instead of returning zero, the buffer is filled with zero bytes
-// instead.  There seem to be archive files that actually depend on this
+// instead. There seem to be archive files that actually depend on this
 // ability to read "beyond" the length of the compressed data.
 
 static size_t read_callback_wrapper(void *buf, size_t buf_len, void *user_data)
@@ -692,7 +692,7 @@ static size_t lha_pm1_read(void *data, uint8_t *buf)
 		return 0;
 	}
 
-	// Read what type of commmand this is.
+	// Read what type of command this is.
 
 	command_type = read_bit(&decoder->bit_stream_reader);
 
@@ -703,7 +703,7 @@ static size_t lha_pm1_read(void *data, uint8_t *buf)
 	}
 }
 
-LHADecoderType lha_pm1_decoder = {
+const LHADecoderType lha_pm1_decoder = {
 	lha_pm1_init,
 	NULL,
 	lha_pm1_read,
@@ -711,4 +711,3 @@ LHADecoderType lha_pm1_decoder = {
 	OUTPUT_BUFFER_SIZE,
 	2048
 };
-
